//
//  AddEditEventViewController.swift
//  Teleasystent
//

import UIKit

class AddEditEventViewController: UIViewController, UIPickerViewDataSource, UIPickerViewDelegate, UITextFieldDelegate, UITextViewDelegate {
    @IBOutlet weak var typeLabel: BaseUILabel!
    @IBOutlet weak var typeInput: UITextField!
    @IBOutlet weak var dateLabel: BaseUILabel!
    @IBOutlet weak var dateInput: UITextField!
    @IBOutlet weak var descriptionLabel: BaseUILabel!
    @IBOutlet weak var descriptionInput: UITextView!
    @IBOutlet weak var assistantLabel: BaseUILabel!
    @IBOutlet weak var assistantInput: UITextField!
    @IBOutlet weak var confirmButton: UIBaseButton!
    
    let typePicker = UIPickerView()
    let assistantPicker = UIPickerView()
    let datePicker = UIDatePicker()
    
//    let typesArray = ["Home", "Special", "Outside"]
//    let assistantsArray = [Utils.getLocString("addevent_assistant_none"), "Jan Nowak", "Adam Kowalski"]
    
    let noAssistantName = Utils.getLocString("addevent_assistant_none")!
    let noEventTypeName = Utils.getLocString("addevent_type_none")!
    let descriptionPlaceholderColor = UIColor.lightGray
    
    var typesArray = [EventTypeData]()
    var assistantsArray = [AssistantData]()
    
    var event: EventData?
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        if let eventTypes = AppDelegate.getInstance().serverManager.eventTypes?.values {
            typesArray = Array(eventTypes)
        } else {
            typesArray = [EventTypeData(typeId: "0", name: noEventTypeName, namePL: noEventTypeName)]
        }
        typesArray = typesArray.sorted(by: {
            return $0.locName < $1.locName
        })
        
        if let assistants = AppDelegate.getInstance().serverManager.assistants?.values {
            assistantsArray = Array(assistants)
        } else {
            assistantsArray = [AssistantData(assistantId: "0", name: noAssistantName, skypeName: "noSkype", mail: "noMail")]
        }
        assistantsArray = assistantsArray.sorted(by: {
            if $0.assistantId == "0" {
                return $1.assistantId != "0"
            }
            if $1.assistantId == "0" {
                return false
            }
            let left = EventsListViewController.assistantName(assistantId: $0.assistantId)
            let right = EventsListViewController.assistantName(assistantId: $1.assistantId)
            return left < right
        })

        typePicker.tag = 100
        typePicker.dataSource = self
        typePicker.delegate = self
        typeInput.inputView = typePicker
        typeInput.inputAccessoryView = createPickerToolbar(doneAction: #selector(typePickerDone))
        typeInput.delegate = self
        
        datePicker.tag = 101
        datePicker.datePickerMode = .dateAndTime
        datePicker.timeZone = TimeZone(secondsFromGMT: 0)
        datePicker.addTarget(self, action: #selector(self.setDate(_:)), for: .valueChanged)
        dateInput.inputView = datePicker
        dateInput.inputAccessoryView = createPickerToolbar(doneAction: #selector(datePickerDone))
        
        descriptionInput.delegate = self
        descriptionInput.layer.borderColor = UIColor(white: 204.0/255.0, alpha: 1.0).cgColor
        descriptionInput.layer.borderWidth = 0.5
        descriptionInput.layer.cornerRadius = 5.0
        
        assistantPicker.tag = 102
        assistantPicker.dataSource = self
        assistantPicker.delegate = self
        assistantInput.inputView = assistantPicker
        assistantInput.inputAccessoryView = createPickerToolbar(doneAction: #selector(assistantPickerDone))
        assistantInput.delegate = self
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        
        self.title = Utils.getLocString(event != nil ? "addevent_editTitle" : "addevent_addTitle")
        typeLabel.text = Utils.getLocString("addevent_typeLabel")
        dateLabel.text = Utils.getLocString("addevent_dateLabel")
        descriptionLabel.text = Utils.getLocString("addevent_descriptionLabel")
        assistantLabel.text = Utils.getLocString("addevent_assistantLabel")
        confirmButton.setTitle(Utils.getLocString("addevent_confirm"), for: .normal)
        assistantInput.placeholder = Utils.getLocString("addevent_assistant_none")
        
        let restoreData = AppDelegate.getInstance().restoreData
        
        let eventTypeId = restoreData.addEditEventTypeId ?? event?.typeId
        let eventTypeIndex = typesArray.index(where: { $0.typeId == eventTypeId }) ?? 0
        typePicker.selectRow(eventTypeIndex, inComponent: 0, animated: false)
        pickerView(typePicker, didSelectRow: eventTypeIndex, inComponent: 0)
        
        let date = restoreData.addEditDate ?? event?.dateObj ?? Date(timeIntervalSinceNow: TimeInterval(24*60*60)).toLocalTime()
        datePicker.setDate(date, animated: false)
        setDate(date: date, endEditing: false)
        
        descriptionInput.text = restoreData.addEditDescription ?? event?.description ?? ""
        textViewDidEndEditing(descriptionInput)
        
        var assistantIndex = 0
        if let eventAssistantId = (restoreData.addEditAssistantId ?? event?.assistantId) {
            assistantIndex = assistantsArray.index(where: { $0.assistantId == eventAssistantId}) ?? assistantIndex
        }
        assistantPicker.selectRow(assistantIndex, inComponent: 0, animated: false)
        pickerView(assistantPicker, didSelectRow: assistantIndex, inComponent: 0)
        
        typeLabel.isAccessibilityElement = false
        typeInput.accessibilityLabel = typeLabel.text
        
        dateLabel.isAccessibilityElement = false
        dateInput.accessibilityLabel = dateLabel.text
        
        descriptionLabel.isAccessibilityElement = false
        descriptionInput.accessibilityLabel = descriptionLabel.text
        
        assistantLabel.isAccessibilityElement = false
        assistantInput.accessibilityLabel = assistantLabel.text
        
        confirmButton.accessibilityLabel = Utils.getLocString("addevent_confirmLabel")
        
        UIAccessibilityPostNotification(UIAccessibilityLayoutChangedNotification, typeInput)
    }
    
    override func viewDidAppear(_ animated: Bool) {
        super.viewDidAppear(animated)
        
//        typeInput.accessibilityFrame = typeInput.accessibilityFrame.union(typeLabel.accessibilityFrame)
//        dateInput.accessibilityFrame = dateInput.accessibilityFrame.union(dateLabel.accessibilityFrame)
//        descriptionInput.accessibilityFrame = descriptionInput.accessibilityFrame.union(descriptionLabel.accessibilityFrame)
//        assistantInput.accessibilityFrame = assistantInput.accessibilityFrame.union(assistantLabel.accessibilityFrame)
    }
    
    override func viewWillDisappear(_ animated: Bool) {
        super.viewWillDisappear(animated)
        
        if isBeingDismissed || isMovingFromParentViewController {
            let restoreData = AppDelegate.getInstance().restoreData
            restoreData.addEditLaunched = false
            restoreData.addEditEventTypeId = nil
            restoreData.addEditDate = nil
            restoreData.addEditDescription = nil
            restoreData.addEditAssistantId = nil
        }
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    func createPickerToolbar(doneAction: Selector?) -> UIToolbar {
        let toolBar = UIToolbar()
        toolBar.barStyle = UIBarStyle.default
        toolBar.isTranslucent = true
        toolBar.sizeToFit()
        let flexButton = UIBarButtonItem(barButtonSystemItem: UIBarButtonSystemItem.flexibleSpace, target: nil, action: nil)
        let doneButton = UIBarButtonItem(title: Utils.getLocString("addevent_pickerDone"), style: UIBarButtonItemStyle.done, target: self, action: doneAction)
        doneButton.isAccessibilityElement = true
        doneButton.accessibilityHint = Utils.getLocString("addevent_pickerDoneHint")
        toolBar.setItems([flexButton, doneButton], animated: false)
        toolBar.isUserInteractionEnabled = true
        return toolBar
    }
    
    @objc func typePickerDone() {
        view.endEditing(true)
        UIAccessibilityPostNotification(UIAccessibilityLayoutChangedNotification, dateInput)
    }
    
    @objc func datePickerDone() {
        view.endEditing(true)
        UIAccessibilityPostNotification(UIAccessibilityLayoutChangedNotification, descriptionInput)
    }
    
    @objc func assistantPickerDone() {
        view.endEditing(true)
        UIAccessibilityPostNotification(UIAccessibilityLayoutChangedNotification, confirmButton)
    }
    
    @IBAction func onConfirmButtonClicked(_ sender: UIBaseButton) {
        guard let eventType = typesArray[safe: typePicker.selectedRow(inComponent: 0)] else {
            handleEmptyEventType()
            return
        }
        guard let assistant = assistantsArray[safe: assistantPicker.selectedRow(inComponent: 0)] else {
            handleEmptyAssistant()
            return
        }
        let date = datePicker.date
        guard date.toGlobalTime().timeIntervalSinceNow > 0 else {
            handleDateInThePast()
            return
        }
        let description = isDescriptionPlaceholderShowed() ? " " : descriptionInput.text

        guard let user = AppDelegate.getInstance().firebaseAuthManager.currentUser else {
            navigationController?.popToRootViewController(animated: false)
            AppDelegate.getInstance().restoreData.clear()
            return
        }
        let userId = user.uid

        let ev = EventData(eventId: event?.eventId, userId: userId, assistantId: assistant.assistantId, date: date, typeId: eventType.typeId, description: description, mark: event?.mark)

        let loadingVC = LoadingDialogController()
        present(loadingVC, animated: false, completion: nil)
        AppDelegate.getInstance().serverManager.addEditEvent(event: ev) { eventData, eventId, error in
            weak var weakSelf = self
            Async.main {
                loadingVC.dismiss(animated: false, completion: nil)
                if let error = error {
                    weakSelf?.handleAddEditEventError(error: error)
                } else if let evId = eventId {
                    weakSelf?.onAddEditEventCompleted(event: eventData, eventId: evId)
                } else {
                    weakSelf?.handleAddEditEventError(error: NSError(domain: "AddEditEvent", code: 1, userInfo: nil))
                }
            }
        }
    }
    
    func handleEmptyEventType() {
        handleEmptyFieldError(fieldName: typeLabel.text ?? "event type", viewToFocus: typeInput)
    }
    
    func handleEmptyAssistant() {
        handleEmptyFieldError(fieldName: assistantLabel.text ?? "assistant", viewToFocus: assistantInput)
    }
    
    func handleDateInThePast() {
        let viewToFocus = dateInput
        let _ = presentErrorDialog(title: nil, message: Utils.getLocString("addevent_dateInPastError"), okButton: Utils.getLocString("common_ok") ?? "OK") {
            Async.main {
                UIAccessibilityPostNotification(UIAccessibilityLayoutChangedNotification, viewToFocus)
            }
        }
    }
    
    func handleEmptyFieldError(fieldName: String, viewToFocus: UIView?) {
        let _ = presentEmptyFieldErrorDialog(fieldName: fieldName) {
            Async.main {
                UIAccessibilityPostNotification(UIAccessibilityLayoutChangedNotification, viewToFocus)
            }
        }
    }
    
    func handleAddEditEventError(error: Error) {
        let _ = presentErrorDialog(error: error) { }
    }
    
    func onAddEditEventCompleted(event: EventData, eventId: String) {
        if let viewControllers = navigationController?.viewControllers {
            for vc in viewControllers {
                if let eventsListVC = vc as? EventsListViewController {
                    eventsListVC.refreshListOnAppear = true
                }
                if let eventVC = vc as? EventViewController {
                    eventVC.event = event
                }
            }
        }
        navigationController?.popViewController(animated: true)
    }
    
    @objc func setDate(_ sender: UIDatePicker) {
        setDate(date: sender.date, endEditing: false)
    }
    
    func setDate(date: Date, endEditing: Bool = true) {
        let selectedDate = Utils.createDateFormatter().string(from: date)
        dateInput.text = selectedDate
        dateInput.accessibilityValue = Utils.dateToAccessibilityString(date: date)
        if endEditing {
            view.endEditing(true)
        }
        AppDelegate.getInstance().restoreData.addEditDate = date
    }
    
    func pickerView(_ pickerView: UIPickerView, numberOfRowsInComponent component: Int) -> Int {
        if pickerView == typePicker {
            return typesArray.count
        } else if pickerView == assistantPicker {
            return assistantsArray.count
        }
        return 0
    }
    
    func pickerView(_ pickerView: UIPickerView, titleForRow row: Int, forComponent component: Int) -> String? {
        if pickerView == typePicker {
            return typesArray[row].locName
        } else if pickerView == assistantPicker {
            return EventsListViewController.assistantName(assistantId: assistantsArray[row].assistantId)
        }
        return ""
    }
    
    func numberOfComponents(in pickerView: UIPickerView) -> Int {
        if pickerView == typePicker {
            return 1
        } else if pickerView == assistantPicker {
            return 1
        }
        return 0
    }
    
    func pickerView(_ pickerView: UIPickerView, didSelectRow row: Int, inComponent component: Int) {
        if pickerView == typePicker {
            typeInput.text = typesArray[row].locName
            AppDelegate.getInstance().restoreData.addEditEventTypeId = typesArray[row].typeId
        } else if pickerView == assistantPicker {
            assistantInput.text = EventsListViewController.assistantName(assistantId: assistantsArray[row].assistantId)
            AppDelegate.getInstance().restoreData.addEditAssistantId = assistantsArray[row].assistantId
        }
    }
    
    func textFieldDidBeginEditing(_ textField: UITextField) {
        if textField == typeInput {
            UIAccessibilityPostNotification(UIAccessibilityLayoutChangedNotification, typePicker)
        } else if textField == assistantInput {
            UIAccessibilityPostNotification(UIAccessibilityLayoutChangedNotification, assistantPicker)
        }
    }
    
    func textField(_ textField: UITextField, shouldChangeCharactersIn range: NSRange, replacementString string: String) -> Bool {
        if textField == typeInput {
            return false
        } else if textField == assistantInput {
            return false
        }
        return true
    }
    
    func textFieldShouldReturn(_ textField: UITextField) -> Bool {
//        if textField == descriptionInput1 {
//            textField.resignFirstResponder()
//        }
        return false
    }
    
    
    func textViewDidBeginEditing(_ textView: UITextView) {
        if isDescriptionPlaceholderShowed() {
            textView.text = nil
            textView.textColor = UIColor.black
        }
    }
    
    func textViewDidEndEditing(_ textView: UITextView) {
        if textView == descriptionInput {
            if textView.text.isEmpty {
                descriptionInput.text = Utils.getLocString("addevent_descriptionHint")
                descriptionInput.textColor = descriptionPlaceholderColor
            } else {
                AppDelegate.getInstance().restoreData.addEditDescription = descriptionInput.text
            }
            UIAccessibilityPostNotification(UIAccessibilityLayoutChangedNotification, assistantInput)
        }
    }
    
    func isDescriptionPlaceholderShowed() -> Bool {
        return descriptionInput.textColor == descriptionPlaceholderColor
    }
    
    func textView(_ textView: UITextView, shouldChangeTextIn range: NSRange, replacementText text: String) -> Bool {
        if text == "\n" {
            textView.resignFirstResponder()
            return false
        }
        return true
    }

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */

}
