//
//  BaseUILabel.swift
//  Tattoo
//

import UIKit

class BaseUILabel: UILabel {
    @IBInspectable var fitToHeightMult: CGFloat = 0.0
    @IBInspectable var fitToWidthMult: CGFloat = 0.0
    @IBInspectable var underlined: Bool = false
    
    override var bounds: CGRect {
        didSet {
            _ = underlineIfEnabled()
            fitTextSize()
        }
    }
    
    override var text: String? {
        didSet {
            _ = underlineIfEnabled()
            fitTextSize()
        }
    }
    
    fileprivate func fitTextSize() {
        if fitToHeightMult > 0 && fitToWidthMult > 0 {
            Utils.fitFontSizeToFrame(self, frame, heightMultiplier: fitToHeightMult, widthMultiplier: fitToWidthMult)
        } else if fitToHeightMult > 0 {
            Utils.fitFontSizeToFrameHeight(self, frame, heightMultiplier: fitToHeightMult)
        } else if fitToWidthMult > 0 {
            Utils.fitFontSizeToFrameWidth(self, frame, widthMultiplier: fitToWidthMult)
        }
    }
    
    override func willMove(toSuperview newSuperview: UIView?) {
        super.willMove(toSuperview: newSuperview)
        _ = underlineIfEnabled()
    }
    
    fileprivate func underlineIfEnabled() -> Bool {
        if underlined {
            guard let text = text else { return false }
            let textRange = NSMakeRange(0, text.characters.count)
            let attributedText = NSMutableAttributedString(string: text)
            attributedText.addAttribute(kCTUnderlineStyleAttributeName as NSAttributedStringKey, value: NSUnderlineStyle.styleSingle.rawValue, range: textRange)
            self.attributedText = attributedText
            return true
        }
        return false
    }

}
