//
//  FirebaseAuthManager.swift
//  Teleasystent
//

import Foundation
import FirebaseAuth
import FirebaseUI

class FirebaseAuthManager {
    var stateChangeHandle: AuthStateDidChangeListenerHandle?
    var loggedUser: User?
    
    var currentUser: User? {
        return loggedUser ?? Auth.auth().currentUser
    }
    
    func onStart() {
        stateChangeHandle = Auth.auth().addStateDidChangeListener { (auth, user) in
            weak var weakSelf = self
            weakSelf?.loggedUser = user
        }
    }
    
    func onStop() {
        if let handle = stateChangeHandle {
            Auth.auth().removeStateDidChangeListener(handle)
        }
    }
    
    func showLoginVC(srcVC: UIViewController, hideCancelButton: Bool = true) -> UIViewController {
        let authUI = FUIAuth.defaultAuthUI()!
        authUI.delegate = srcVC as? FUIAuthDelegate
        authUI.providers = [FUIGoogleAuth(), FUIFacebookAuth()]
        authUI.shouldHideCancelButton = hideCancelButton
        if let bundlePath = Bundle.main.path(forResource: "FirebaseAuthUI", ofType: "strings") {
            authUI.customStringsBundle = Bundle(path: bundlePath)
        }
        let authVC = authUI.authViewController()
        srcVC.present(authVC, animated: false, completion: nil)
        return authVC
    }
    
    func logout() {
        try? Auth.auth().signOut()
    }
    
    func printCurrentUserToken() {
        currentUser?.getIDTokenForcingRefresh(true) { idToken, error in
            if let error = error {
                print(error.localizedDescription)
            } else {
                print(idToken ?? "no token")
            }
        }
    }
    
}
