
import UIKit

private let messageKey = "message"
class LoadingDialogController: UIViewController {

    fileprivate let activityView = LoadingView()
    
    convenience init() {
        let message = Utils.getLocString("loading_wait") ?? "Loading, please wait"
        self.init(message: message)
    }

    init(message: String) {
        super.init(nibName: nil, bundle: nil)
        modalTransitionStyle = .crossDissolve
        modalPresentationStyle = .overFullScreen
        activityView.messageLabel.text = message
        view = activityView
    }

    required init?(coder aDecoder: NSCoder) {
        activityView.messageLabel.text = aDecoder.decodeObject(forKey: messageKey) as? String
        super.init(coder: aDecoder)
    }
    
    override func encode(with aCoder: NSCoder) {
        if let msg = activityView.messageLabel.text {
            aCoder.encode(msg, forKey: messageKey)
        }
        super.encode(with: aCoder)
    }
}

private class LoadingView: UIView {

    let activityIndicatorView = UIActivityIndicatorView(activityIndicatorStyle: .whiteLarge)
    let boundingBoxView = UIView(frame: CGRect.zero)
    let messageLabel = UILabel(frame: CGRect.zero)

    init() {
        super.init(frame: CGRect.zero)

        backgroundColor = UIColor(white: 0.0, alpha: 0.5)

        boundingBoxView.backgroundColor = UIColor(white: 0.0, alpha: 1.0)
        boundingBoxView.layer.cornerRadius = 12.0
        boundingBoxView.layer.borderColor = UIColor.white.cgColor
        boundingBoxView.layer.borderWidth = 0.005*UIScreen.main.bounds.width

        activityIndicatorView.startAnimating()

        messageLabel.font = UIFont.boldSystemFont(ofSize: UIFont.labelFontSize)
        messageLabel.textColor = UIColor.white
        messageLabel.textAlignment = .center
        messageLabel.shadowColor = UIColor.black
        messageLabel.shadowOffset = CGSize(width: 0.0, height: 1.0)
        messageLabel.numberOfLines = 0

        addSubview(boundingBoxView)
        addSubview(activityIndicatorView)
        addSubview(messageLabel)
    }

    required convenience init?(coder aDecoder: NSCoder) {
        self.init()
    }

    override func layoutSubviews() {
        super.layoutSubviews()

        boundingBoxView.frame.size.width = 0.6*UIScreen.main.bounds.width
        boundingBoxView.frame.size.height = 0.5*boundingBoxView.frame.size.width
        boundingBoxView.frame.origin.x = ceil((bounds.width / 2.0) - (boundingBoxView.frame.width / 2.0))
        boundingBoxView.frame.origin.y = ceil((bounds.height / 2.0) - (boundingBoxView.frame.height / 2.0))
        
        func posInBounding(_ relX: CGFloat, relY: CGFloat, offsetX: CGFloat, offsetY: CGFloat) -> CGPoint {
            return CGPoint(x: boundingBoxView.frame.origin.x + relX*boundingBoxView.frame.size.width + offsetX,
                           y: boundingBoxView.frame.origin.y + relY*boundingBoxView.frame.size.height + offsetY)
        }

        activityIndicatorView.transform = CGAffineTransform.identity
        let indicatorScale = 0.4*boundingBoxView.frame.height / activityIndicatorView.frame.height
        activityIndicatorView.transform = CGAffineTransform(scaleX: indicatorScale, y: indicatorScale)
        activityIndicatorView.frame.origin = posInBounding(0.5, relY: 0.4, offsetX: -activityIndicatorView.frame.width/2, offsetY: -activityIndicatorView.frame.height/2)

        messageLabel.frame.size.width = 0.85*boundingBoxView.frame.width
        messageLabel.frame.size.height = 0.2*boundingBoxView.frame.height
        messageLabel.frame.origin = posInBounding(0.5, relY: 0.8, offsetX: -messageLabel.frame.width/2, offsetY: -messageLabel.frame.height/2)
        Utils.fitFontSizeToFrame(messageLabel, messageLabel.frame)
    }
}
