//
//  UIBaseButton.swift
//  Tattoo
//

import UIKit

class UIBaseButton: UIButton {
    var highlightedCallback: ((Bool) -> Void)?
    
    @IBInspectable var fitToHeightMult: CGFloat = 0.0
    @IBInspectable var fitToWidthMult: CGFloat = 0.0
    @IBInspectable var roundedCorners: CGFloat = 0.0
    
    override var isHighlighted: Bool {
        didSet {
            if let cb = highlightedCallback {
                cb(isHighlighted)
            }
        }
    }
    
    override var bounds: CGRect {
        didSet {
            fitTextSize()
        }
    }
    
    override func setTitle(_ title: String?, for state: UIControlState) {
        super.setTitle(title, for: state)
        fitTextSize()
    }
    
    fileprivate func fitTextSize() {
        guard let label = titleLabel else { return }
        if fitToHeightMult > 0 && fitToWidthMult > 0 {
            Utils.fitFontSizeToFrame(label, frame, heightMultiplier: fitToHeightMult, widthMultiplier: fitToWidthMult)
        } else if fitToHeightMult > 0 {
            Utils.fitFontSizeToFrameHeight(label, frame, heightMultiplier: fitToHeightMult)
        } else if fitToWidthMult > 0 {
            Utils.fitFontSizeToFrameWidth(label, frame, widthMultiplier: fitToWidthMult)
        }
    }
    
    override func layoutSubviews() {
        super.layoutSubviews()
        if roundedCorners > 0.0 {
            clipsToBounds = true
            layer.cornerRadius = roundedCorners
        }
    }
    
    func setRoundedCorners(radius: CGFloat = 8.0) {
        clipsToBounds = true
        layer.cornerRadius = radius
    }

    
    
}
