//
//  UIRelInsetButton.swift
//  Tattoo
//

import UIKit

class UIRelInsetButton: UIButton {
    
    @IBInspectable var relInsetLeft: CGFloat = 0 {
        didSet {
            updateInset()
        }
    }
    
    @IBInspectable var relInsetTop: CGFloat = 0 {
        didSet {
            updateInset()
        }
    }
    
    @IBInspectable var relInsetRight: CGFloat = 0 {
        didSet {
            updateInset()
        }
    }
    
    @IBInspectable var relInsetBottom: CGFloat = 0 {
        didSet {
            updateInset()
        }
    }
    
    override var bounds: CGRect {
        didSet {
            updateInset()
        }
    }
    
    override init(frame: CGRect) {
        super.init(frame: frame)
    }
    
    required init?(coder aDecoder: NSCoder) {
        super.init(coder: aDecoder)
    }
    
    override func setTitle(_ title: String?, for state: UIControlState) {
        super.setTitle(title, for: state)
        updateInset()
    }

    fileprivate func updateInset() {
        let width = bounds.width
        let height = bounds.height
        contentEdgeInsets = UIEdgeInsets(top: relInsetTop*height, left: relInsetLeft*width, bottom: relInsetBottom*height, right: relInsetRight*width)
//        titleLabel?.adjustsFontSizeToFitWidth = true
//        titleLabel?.minimumScaleFactor = 0.5
        if let text = titleLabel {
            Utils.fitFontSizeToFrame(text, CGRect(x: contentEdgeInsets.left, y: contentEdgeInsets.top, width: width-contentEdgeInsets.right-contentEdgeInsets.left, height: height-contentEdgeInsets.bottom-contentEdgeInsets.top))
        }
        setNeedsDisplay()
//        print("screen scale=\(UIScreen.mainScreen().scale), nativeScale=\(UIScreen.mainScreen().nativeScale)")
//        print("screen bounds\(UIScreen.mainScreen().bounds), nativeBounds=\(UIScreen.mainScreen().nativeBounds)")
//        print("frame size=\(frame.size)")
    }

}
