//
//  UserInfoViewController.swift
//  Teleasystent
//

import UIKit

class UserInfoViewController: UIViewController, UITextFieldDelegate {
    @IBOutlet weak var nameLabel: BaseUILabel!
    @IBOutlet weak var nameInput: UITextField!
    @IBOutlet weak var emailLabel: BaseUILabel!
    @IBOutlet weak var emailInput: UITextField!
    @IBOutlet weak var skypeLabel: BaseUILabel!
    @IBOutlet weak var skypeInput: UITextField!
    @IBOutlet weak var dogLabel: BaseUILabel!
    @IBOutlet weak var dogSwitch: UISwitch!
    @IBOutlet weak var stickLabel: BaseUILabel!
    @IBOutlet weak var stickSwitch: UISwitch!
    @IBOutlet weak var registerButton: UIBaseButton!
    
    
    var userId: String!
    var user: UserData?
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        
        navigationItem.leftBarButtonItem = UIBarButtonItem(title: Utils.getLocString("common_back")!, style: .plain, target: self, action: #selector(onBackPressed))
        self.title = Utils.getLocString("userinfo_title")
        
        guard let user = AppDelegate.getInstance().firebaseAuthManager.currentUser else {
            navigationController!.popViewController(animated: true)
            return
        }
        self.userId = user.uid
        
        nameLabel.text = Utils.getLocString("userinfo_nameLabel")
        nameInput.placeholder = Utils.getLocString("userinfo_nameHint")
        emailLabel.text = Utils.getLocString("userinfo_emailLabel")
        emailInput.placeholder = Utils.getLocString("userinfo_emailHint")
        skypeLabel.text = Utils.getLocString("userinfo_skypeLabel")
        skypeInput.placeholder = Utils.getLocString("userinfo_skypeHint")
        dogLabel.text = Utils.getLocString("userinfo_dogLabel")
        stickLabel.text = Utils.getLocString("userinfo_stickLabel")
        registerButton.setTitle(Utils.getLocString("userinfo_register"), for: .normal)
        
        nameInput.delegate = self
        emailInput.delegate = self
        skypeInput.delegate = self
        
        nameInput.text = user.displayName
        emailInput.text = user.email
        
        nameLabel.isAccessibilityElement = false
        nameInput.accessibilityLabel = nameLabel.text
        
        emailLabel.isAccessibilityElement = false
        emailInput.accessibilityLabel = emailLabel.text
        
        skypeLabel.isAccessibilityElement = false
        skypeInput.accessibilityLabel = skypeLabel.text
        
        dogLabel.isAccessibilityElement = false
        dogSwitch.accessibilityLabel = dogLabel.text
        
        stickLabel.isAccessibilityElement = false
        stickSwitch.accessibilityLabel = stickLabel.text
    }
    
    override func viewDidAppear(_ animated: Bool) {
        super.viewDidAppear(animated)
        
//        nameInput.accessibilityFrame = nameInput.accessibilityFrame.union(nameLabel.accessibilityFrame)
//        emailInput.accessibilityFrame = emailInput.accessibilityFrame.union(emailLabel.accessibilityFrame)
//        skypeInput.accessibilityFrame = skypeInput.accessibilityFrame.union(skypeLabel.accessibilityFrame)
//        dogSwitch.accessibilityFrame = dogSwitch.accessibilityFrame.union(dogLabel.accessibilityFrame)
//        stickSwitch.accessibilityFrame = stickSwitch.accessibilityFrame.union(stickLabel.accessibilityFrame)
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    @objc func onBackPressed() {
        AppDelegate.getInstance().firebaseAuthManager.logout()
        navigationController?.popViewController(animated: true)
    }
    
    @IBAction func onRegisterButtonClicked(_ sender: UIBaseButton) {
        guard let name = nameInput.text, !name.isEmpty else {
            handleEmptyNameError()
            return
        }
        guard let email = emailInput.text, !email.isEmpty else {
            handleEmptyEmailError()
            return
        }
        guard email.isEmail else {
            handleWrongEmailError()
            return
        }
        guard let skypeName = skypeInput.text, !skypeName.isEmpty else {
            handleEmptySkypeError()
            return
        }
        let userData = UserData(userId: userId, name: name, skypeName: skypeName, mail: email, dog: dogSwitch.isOn, stick: stickSwitch.isOn)
        let loadingVC = LoadingDialogController()
        present(loadingVC, animated: false, completion: nil)
        AppDelegate.getInstance().serverManager.addOrEditUser(user: userData) { success, error in
            weak var weakSelf = self
            Async.main {
                loadingVC.dismiss(animated: false, completion: nil)
                if let error = error {
                    weakSelf?.handleAddUserError(error: error)
                } else if !success {
                    weakSelf?.handleAddUserError(error: NSError(domain: "ServerError", code: 1, userInfo: nil)) // TODO opis bledu
                } else {
                    weakSelf?.launchEventsListVC(user: userData)
                }
            }
        }
    }
    
    func launchEventsListVC(user: UserData) {
        self.user = user
        performSegue(withIdentifier: "showEventsListSegue", sender: self)
    }
    
    func handleEmptyNameError() {
        handleEmptyFieldError(fieldName: nameLabel.text ?? "name", viewToFocus: nameInput)
    }
    
    func handleEmptyEmailError() {
        handleEmptyFieldError(fieldName: emailLabel.text ?? "e-mail", viewToFocus: emailInput)
    }
    
    func handleEmptySkypeError() {
        handleEmptyFieldError(fieldName: skypeLabel.text ?? "skype", viewToFocus: skypeInput)
    }
    
    func handleEmptyFieldError(fieldName: String, viewToFocus: UIView?) {
        let _ = presentEmptyFieldErrorDialog(fieldName: fieldName) {
            Async.main {
                UIAccessibilityPostNotification(UIAccessibilityLayoutChangedNotification, viewToFocus)
            }
        }
    }
    
    func handleWrongEmailError() {
        let viewToFocus = emailInput
        let _ = presentWrongFieldErrorDialog(fieldName: emailLabel.text ?? "e-mail") {
            Async.main {
                UIAccessibilityPostNotification(UIAccessibilityLayoutChangedNotification, viewToFocus)
            }
        }
    }
    
    func handleAddUserError(error: Error) {
        print("AddUser error: \(error.localizedDescription)")
        let _ = presentErrorDialog(error: error) { }
    }
    
    
    func textFieldShouldReturn(_ textField: UITextField) -> Bool {
        if textField == nameInput {
            emailInput.becomeFirstResponder()
        } else if textField == emailInput {
            skypeInput.becomeFirstResponder()
        } else if textField == skypeInput {
            skypeInput.resignFirstResponder()
            UIAccessibilityPostNotification(UIAccessibilityLayoutChangedNotification, dogSwitch)
        }
        return false
    }
    
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        if let eventsListVC = segue.destination as? EventsListViewController {
            eventsListVC.user = user
        }
    }
    

}
